@@ -16,7 +16,7 @@ use strict;
 use warnings;
 no warnings 'once';
 
-our $VERSION = '0.009000';
+our $VERSION = '0.009001';
 $VERSION = eval $VERSION;
 
 use Carp ();
@@ -104,7 +104,7 @@ sub _parse_options {
       if ($NUMOPTS{$opt}) {
         $value
           = !defined $value ? 0
-          : !$value ? 0+'inf'
+          : !$value ? 1e10000
           : 0+$value;
       }
       $opts{$opt} = $value;
