@@ -3,11 +3,13 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-$^P |= $] >= 5.010 ? 0x400 : do {
-  *DB::DB = sub {}
-    unless defined &DB::DB;
-  0x02;
-};
+sub import {
+  $^P |= $] >= 5.010 ? 0x400 : do {
+    *DB::DB = sub {}
+      unless defined &DB::DB;
+    0x02;
+  };
+}
 
 my $want_color = $^O ne 'MSWin32' ? 1 : eval {
   require Win32::Console::ANSI;
@@ -16,7 +18,7 @@ my $want_color = $^O ne 'MSWin32' ? 1 : eval {
 };
 
 sub source_trace {
-  my ($skip, $context) = @_;
+  my ($skip, $context, $evalonly) = @_;
   $skip ||= 1;
   $skip += $Carp::CarpLevel;
   $context ||= 3;
@@ -25,6 +27,8 @@ sub source_trace {
   while (my ($pack, $file, $line) = (caller($i++))[0..2]) {
     next
       if $Carp::Internal{$pack} || $Carp::CarpInternal{$pack};
+    next
+      if $evalonly && $file !~ /^\(eval \d+\)(?:\[|$)/;
     my $lines = _get_content($file) || next;
 
     my $start = $line - $context;
@@ -44,6 +48,8 @@ sub source_trace {
     }
     push @out, $context;
   }
+  return ''
+    if !@out;
   return join(('=' x 75) . "\n",
     '',
     join(('-' x 75) . "\n", @out),
@@ -57,7 +63,7 @@ sub _get_content {
   if (exists $::{'_<'.$file} && @{ '::_<'.$file }) {
     return \@{ '::_<'.$file };
   }
-  elsif ($file =~ /^\(eval \d+\)$/) {
+  elsif ($file =~ /^\(eval \d+\)(?:\[.*\])?$/) {
     return ["Can't get source of evals unless debugger available!"];
   }
   elsif (open my $fh, '<', $file) {
@@ -65,7 +71,7 @@ sub _get_content {
     return \@lines;
   }
   else {
-    return ["Source not available!"];
+    return ["Source file not available!"];
   }
 }
 
